package
Version:
v0.0.0-...-15f35aa
Opens a new window with list of versions in this module.
Published: May 26, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
DefaultConfigFilePath = "config/default.yaml"
SentryFlowDefaultFilterServerPort = 8081
)
type Config struct {
Filters *filters `json:"filters"`
Receivers *receivers `json:"receivers"`
Exporter *exporterConfig `json:"exporter"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.